@@ -6,35 +6,49 @@ from .keys import bing_key
 
 
 class Bing(Base):
-    provider = 'bing'
-    api = 'Bing Maps REST Services'
-    url = 'http://dev.virtualearth.net/REST/v1/Locations'
-    _description = 'The Bing™ Maps REST Services Application Programming Interface (API)\n'
-    _description += 'provides a Representational State Transfer (REST) interface to\n'
-    _description += 'perform tasks such as creating a static map with pushpins, geocoding\n'
-    _description += 'an address, retrieving imagery metadata, or creating a route.'
-    _api_reference = ['[{0}](http://msdn.microsoft.com/en-us/library/ff701714.aspx)'.format(api)]
-    _api_parameter  = [':param ``key``: (optional) use your own API Key from Bing.']
+    """
+    Bing Maps REST Services
+    =======================
+    The Bing™ Maps REST Services Application Programming Interface (API)
+    provides a Representational State Transfer (REST) interface to
+    perform tasks such as creating a static map with pushpins, geocoding
+    an address, retrieving imagery metadata, or creating a route.
 
-    def __init__(self, location, key=bing_key):
+    API Reference
+    -------------
+    http://msdn.microsoft.com/en-us/library/ff701714.aspx
+
+    OSM Quality (4/6)
+    -----------------
+    [ ] addr:housenumber
+    [ ] addr:street
+    [x] addr:city
+    [x] addr:state
+    [x] addr:country
+    [x] addr:postal
+    """
+    provider = 'bing'
+    method = 'geocode'
+
+    def __init__(self, location, **kwargs):
+        self.url = 'http://dev.virtualearth.net/REST/v1/Locations'
         self.location = location
         self.json = dict()
         self.parse = dict()
-        self.params = dict()
-        self.params['maxResults'] = 1
-        self.params['key'] = key
-        self.params['q'] = location
+        self.content = None
+        self.params = {
+            'q': location,
+            'o': 'json',
+            'key': kwargs.get('key', bing_key),
+            'maxResults': 1,
+        }
+        self._initialize(**kwargs)
+        self._bing_catch_errors()
 
-        # Initialize
-        self._connect()
-        self._parse(self.content)
-        self._json()
-        self.bbox
-
-        # Bing catch errors
+    def _bing_catch_errors(self):
         status = self._get_json_str('statusDescription')
         if not status == 'OK':
-            self._error = status
+            self.error = status
 
     @property
     def lat(self):
@@ -45,12 +59,28 @@ class Bing(Base):
         return self._get_json_float('coordinates-1')
 
     @property
-    def route(self):
+    def address(self):
+        return self._get_json_str('address-formattedAddress')
+
+    @property
+    def housenumber(self):
+        return ''
+
+    @property
+    def street(self):
         return self._get_json_str('address-addressLine')
 
     @property
-    def address(self):
-        return self._get_json_str('address-formattedAddress')
+    def city(self):
+        return self._get_json_str('address-locality')
+
+    @property
+    def state(self):
+        return self._get_json_str('address-adminDistrict')
+
+    @property
+    def country(self):
+        return self._get_json_str('address-countryRegion')
 
     @property
     def quality(self):
@@ -72,19 +102,6 @@ class Bing(Base):
         east = self._get_json_float('bbox-3')
         return self._get_bbox(south, west, north, east)
 
-    @property
-    def city(self):
-        return self._get_json_str('address-locality')
-
-    @property
-    def state(self):
-        return self._get_json_str('address-adminDistrict')
-
-    @property
-    def country(self):
-        return self._get_json_str('address-countryRegion')
-
 if __name__ == '__main__':
-    g = Bing('453 Booth Street, Ottawa ON')
-    g.help()
+    g = Bing('1552 Payette dr., Ottawa ON')
     g.debug()
\ No newline at end of file
